*  CONSUMO.DO
*@ PROGRAMA PARA VALORAR CONSUMO DE COMIDA (COMPRADA Y OBTENIDA DE OTRA FORMA, NO COMPRADA)
*@ Y CONSUMO NO COMIDA (GASTOS NO ALIMENTICIOS, VALOR DEL USO DE BIENES Y CASA, OTROS) POR HOGAR
*@ TIENE UNA SERIE DE VERIFICACIONES Y EXPLORA Y LISTA CASOS RAROS
* AGOSTO 03 rerun MARCH 05

/*  Este programa usa los archivos de la linea de base
 
     gastos_a00.dta
     gastos_b100.dta
     gastos_b200.dta
     gastos_b300.dta
     gastos_b400.dta
     viviendalb00.dta
     poblacionlb00.dta
     equipos00.dta 

    Y genera tres archivos 
   
     g_alimentos00   (Gastos alimenticios incluyendo no compradas - componentes)
     g_noalimentos00 (Gastos no alimenticios - componentes)
     g_total00       (Gastos totales)

*/
   
*------------------------------------------------------------------------------------------

global LB00  "d:\nicaragua\rps\data\baseline00\data\stata_clean" 

*------------------------------------------------------------------------------------------

/* Banco Central de Nicaragua Tipo de Cambio Nominal (promedios)
   agosto     2000  12.78
   septiembre 2000  12.84 */
 
global EXRATE "12.8"

*------------------------------------------------------------------------------------------

use hogarid using $LB00\viviendalb00 
sort hogarid 
save $LB00\tmpdigit , replace 

*------------------------------------------------------------------------------------------
* Gastos Alimentos
*------------------------------------------------------------------------------------------

*@GASTOS COMIDAS COMPRADAS DE SECCION 8A

*Usar archivo de gastos alimenticios

use $LB00\gastos_a00 

*solo mantener registros con datos de comida comprada

keep if  s8ap03==1

*mantener registros con 1.datos de hogar; 2. alimento; 3. cada cuanto se compra; 4. cantidad; 5. unidad; 6. valor; 7 forma en que se obtiene alimento

keep  hogarid s8ap00 s8ap04 s8ap05a s8ap05b s8ap06
rename s8ap00  alimento
rename s8ap04  periodo
rename s8ap05a cantidad
rename s8ap05b unidad
rename s8ap06  valor

*generar variable para indicar que este archivo es de comida comprada (label 6=comprado)

gen byte tipogast=6

*guardar archivo de comida comprada

save $LB00\tempfood, replace

*@GASTOS COMIDAS OBTENIDAS DE OTRA FORMA, NO COMPRADAS DE SECCION 8A

*Usar archivo de gastos alimenticios

use $LB00\gastos_a00

*solo mantener registros con datos de comida no comprada

keep if s8ap07~=6

*mantener registros con 1.datos de hogar; 2. alimento; 3. cada cuanto se compra; 4. cantidad; 5. unidad; 6. valor

keep hogarid s8ap00 s8ap08 s8ap09a s8ap09b s8ap10 s8ap07

*renombrar y ordenar variables para que se puedan unir con el archivo primero de comida comprada

order hogarid s8ap00 s8ap08 s8ap09a s8ap09b s8ap10 s8ap07
rename s8ap00 alimento
rename s8ap08 periodo
rename s8ap09a cantidad
rename s8ap09b unidad
rename s8ap10 valor
rename s8ap07 tipogast

label define s8ap07 6 "Comida comprada" 99"Comida comprada (8B)", modify

*unir datos de comida no comprada, con datos de comida comprada

append using $LB00\tempfood

*determinar hogares sin datos de comida comprada en Seccion 8A

gen compra=1 if tipogas==6
egen nodata1=mean(compra), by (hogarid)
label var nodata1 "No tiene comida comprada en 8A"
drop compra

sort hogarid 
merge hogarid using $LB00\tmpdigit , nokeep
assert _m == 3
drop _m 

*determinar hogares sin datos de comida de produccion propia etc. en Seccion 8A

gen compra=1 if tipogas==1
egen nodata2=mean(compra), by (hogarid)
label var nodata2 "Sin datos de Produccion Propia"
drop compra

sort hogarid 
by hogarid : gen first = _n

* Hogares que no reportan ninguna comida comprada, todos han hecho verificado
li hogarid if (nodata1==. & nodata2~=. & first==1) , noobs nolab

* Hogares que no reportan ninguna comida comprada ni producida, todos han hecho verificado
li hogarid if (nodata1==. & nodata2==. & first==1) , noobs nolab


save $LB00\tempfood, replace 

* Incluir gastos en comida fuera del hogar de seccion B1

use hogarid s8b1p00 s8b1p03 s8b1p04 using $LB00\gastos_b100
keep if s8b1p00==5 & s8b1p03==1 
g alimento = 99
g periodo  = 2
rename s8b1p04 valor
g tipogast = 99
drop s8b1p00 s8b1p03 
save $LB00\foodafuera, replace 

*guardar archivo con datos de dos registros y comida afuera del hogar

use $LB00\tempfood
append using $LB00\foodafuera 

drop nodata1 nodata2
sort hogarid
format alimento %10.0f
save $LB00\tempfood, replace 

erase $LB00\foodafuera.dta


*@Calcular gasto anual en comida por hogar

gen anual=periodo
tab anual, missing
recode  anual  1=365  2=52  3=24  4=12  5=4  6=2  7=1
assert anual ~=.
label var anual "Anualizar el periodo"

*@ VERIFICACIONES

*Generar el gasto anual en comida por hogar en Cordobas y Dolares al cambio de $EXRATE

gen gastoyr=anual*valor
label var gastoyr "Gast anual TIPO comida C$"
gen gastousd=gastoyr/$EXRATE
label var gastousd "Gast anual TIPO comida EU$ $EXRATE"
keep hogarid alimento tipogast gastousd gastoyr
label define comida 99 "Comida Afuera hogar (8B)" , modify 
 
compress 
label data "LdB 2000 : Gastos anuales alimenticios - componentes"
sort hogarid alimento 
save $LB00\g_alimentos00, replace

collapse (sum)  tgastoyr=gastoyr tgastous=gastousd, by(hogarid)
label var tgastoyr "Gast anual TOTAL comida C$"
label var tgastous "Gast anual TOTAL comida EU$ $EXRATE"
sort hogarid

*Unir archivo de gastos de comida con vivienda para ver No. de personas por hogar

merge hogarid using $LB00\viviendalb00
assert _merge==3 
drop _m

keep hogarid tgastous i09 tgastoyr
sort hogarid
save $LB00\tfood, replace
 
*Crear gastos per capita en comida por hogar

gen pcfood=tgastoyr/i09
label var pcfood "Gast anual TOTAL PC comida C$"
gen pcfoodus=tgastous/i09
label var pcfoodus "Gast anual TOTPC comida EU$ $EXRATE"
sort hogarid

save $LB00\tfood, replace

merge hogarid using $LB00\tempfood
assert _merge==3 
drop _m

sort hogarid
gen conteo=1 if hogarid~=hogarid[_n-1]
save $LB00\tempfood, replace

*lista de hogares con gasto anual en comida muy pequeno

gen pcgastous=tgastous/i09 
sort pcgastous

li hogarid tgastous pcgastous if (pcgastous<30) & conteo==1 , noobs nolab /* approx less than $30 */

*lista de hogares con gasto anual en comida demasiado grande

li hogarid tgastous pcgastous if (tgastous>4000|pcgastous>1000) & conteo==1 , noobs nolab /* approx > $1000 */

*esto cuenta los hogares que tienen muy pocos registros de comida para conteo anual

egen cnt=count(i09), by (hogarid)
gsort cnt

li hogarid tgastous pcgastous if cnt<4 & conteo==1 , noobs nolab /* 3 or fewer */

erase $LB00\tempfood.dta

use $LB00\g_alimentos00 , clear  
drop gastousd
save $LB00\g_alimentos00, replace 

*------------------------------------------------------------------------------------------
* Gastos No Alimenticios
*------------------------------------------------------------------------------------------

clear


*@ARCHIVO DE GASTOS EN NO COMIDAS

*Estimar los gastos anuales que no son de comida
*Hay cuatro archivos: gastos_b1=semanal; gastos_b2=mensual; gastos_b3=6 meses; gastos_b4=anual

*gastos semanales en taxis, periodicos, telefono, comidas, etc 1-5

use $LB00\gastos_b100, clear
drop if s8b1p00==5 /* comida ya considerada arriba */
gen gastoyr= s8b1p04 *52
rename s8b1p00 tipo
keep hogarid tipo gastoyr
save $LB00\temp1, replace

*gastos mensuales en jabon, shampoo, escobas, fosforos, etc 1-25

use $LB00\gastos_b200, clear
gen gastoyr= s8b2p02*12
rename s8b2p00 tipo
keep hogarid tipo gastoyr
replace tipo=tipo+5
save $LB00\temp2, replace

*gastos dos veces por an~o en prendas de vestir, zapatos, vajillas, cortinas, etc. 1-14

use $LB00\gastos_b300, clear
gen gastoyr= s8b3p02*2
rename s8b3p00 tipo
keep hogarid tipo gastoyr
replace tipo=tipo+30
save $LB00\temp3, replace

*gastos anuales en reparacion de casa, muebles, etc 1-17

use $LB00\gastos_b400, clear
rename s8b4p02 gastoyr
rename s8b4p00 tipo
keep hogarid tipo gastoyr
replace tipo=tipo+44

*Unir todos los archivos de gastos que no son de comida

append using $LB00\temp1
append using $LB00\temp2
append using $LB00\temp3
drop if gastoyr==.

*Generar gastos de NO comida en dolares al cambio de $EXRATE

gen gastousd=gastoyr/$EXRATE
label var gastoyr  "Gast anual TIPO NO comida 8B C$
label var gastousd "Gast anual TIPO NO comida 8B EU$ $EXRATE"
rename tipo tiponf
label var tiponf "TIPO Gasto No Comida"
label drop _all

label data "LdB 2000 : Gastos anuales no alimenticios - componentes"

compress 
sort hogarid tiponf 
save $LB00\g_noalimentos00, replace

collapse (sum)  tgastoyr=gastoyr tgastous=gastousd , by(hogarid)

label var tgastoyr  "Gast anual TOT en NO comida de Seccion 8B : C$"
label var tgastous  "Gast anual TOT en NO comida de Seccion 8B : EU$ ($EXRATE)"

sort hogarid 
save $LB00\tnofood, replace

erase $LB00\temp1.dta
erase $LB00\temp2.dta
erase $LB00\temp3.dta

*@ VERIFICACIONES

rename tgastoyr noalim 
rename tgastous noalimeu

sort hogarid
merge hogarid using $LB00\tfood
tab _merge
assert _merge~=1
drop _merge
recode noalim    .=0 
recode noalimeu  .=0 

rename tgastoyr alim
rename tgastous alimeu

*identificar errores

egen avg=mean(noalimeu)
gen error=1 if noalimeu==0
replace error=2 if (avg/noalimeu>10)
replace error=3 if (noalimeu/avg>10)
replace error=1 if noalimeu==0
label define error 1"Non-food=0" 2"Non-Food is 10x<avg" 3"Non-Food is 10x>avg"
label values error error
label var error "Errores en No Comida"

drop avg
egen avg=mean(alimeu)
gen errorf=1 if (avg/alimeu>10)
replace errorf=2 if (alim/avg>10)
label define errorf 1"Food is 10x<avg" 2"Food is 10x>avg"
label values errorf errorf
label var errorf "Errores en Comida"
drop avg

gen total   = noalim   + alim

order hogarid i09 alim noalim alimeu noalimeu error errorf
gen errort=1 if total==.
drop total noalimeu
label var errort "Errores en Total, falta info"

sort hogarid
save $LB00\g_total00, replace

erase $LB00\tfood.dta
erase $LB00\tnofood.dta

use $LB00\g_noalimentos00 
format tiponf %5.0f 
format gastoyr %9.0g
drop gastousd 
save $LB00\g_noalimentos00, replace 


*-----------------------------------------------------------------------------------------
* Gastos del hogar incluyendo luz, agua, renta (imputada por el hogar)
*------------------------------------------------------------------------------------------

use hogarid s3ap03a s3ap03b s3ap04 s3ap05 s3ap08a s3ap08b s3ap11a s3ap11b s3ap14a s3ap14b s3ap15a s3ap15b s3ap19 s3ap21 using $LB00\viviendalb00, clear

rename s3ap03a renta1
rename s3ap05  renta2
rename s3ap08a agua
rename s3ap11a basura
rename s3ap14a electric
rename s3ap15a luz
rename s3ap19  fuel
rename s3ap21  telefono

recode s3ap03b 3=12
replace renta1=renta1*s3ap03b
replace renta2=renta2*12
recode renta1 .=0 
recode renta2 .=0
gen renta = renta1 + renta2 

recode s3ap11b 1=52 2=26 3=12 4=4 5=2 6=1
replace basura=basura*s3ap11b

recode s3ap14b 1=52 2=26 3=12 4=4 5=2 6=1
replace electric=electric*s3ap14b

recode s3ap15b 1=52 2=26 3=12 4=4 5=2 6=1
replace luz=luz*s3ap15b

replace fuel=fuel*12
replace telefono=telefono*12

recode telefono .=0 
recode agua     .=0
recode basura   .=0
recode electric .=0
recode luz      .=0
recode fuel     .=0

sort hogarid
save $LB00\g_otros, replace

use $LB00\g_total00 
merge hogarid using $LB00\g_otros
assert _m==3 
drop _m s3ap14b s3ap03b s3ap04 renta1 renta2 s3ap08b s3ap11b s3ap15b
label var renta "Estimacion de renta"

sort hogarid
save $LB00\g_total00 , replace

*-----------------------------------------------------------------------------------------
* Gastos de la Salud
*------------------------------------------------------------------------------------------

use hogarid s4p28b s4p29b s4p36 s4p39b s4p43b s4p44b s4p46b s4p47 using $LB00\poblacionlb00

gen salud=s4p47*12

* Algunos hogares reportaron gastos en salud que eran "de una vez" acuerdo a la boleta, entonces no se multiplica por 12

replace salud=s4p47 if hogarid=="00174001"   |hogarid=="00275101"   |hogarid=="00304501"   |hogarid=="00306301"   |hogarid=="00357701"   |hogarid=="00400801"   |hogarid=="00545501"   |hogarid=="00589001"   |hogarid=="00634501"   |hogarid=="00634701"   |hogarid=="00653401"   |hogarid=="00673801"   |hogarid=="00756901"   |hogarid=="00801101"   |hogarid=="00804901"   |hogarid=="00936001"   |hogarid=="00973001"   |hogarid=="00974701"   

recode salud .=0
collapse (sum) salud s4p28b s4p29b s4p36 s4p39b s4p43b s4p44b s4p46b, by (hogarid)
keep salud hogarid 
sort hogarid
save $LB00\g_salud, replace

use $LB00\g_total00
merge hogarid using $LB00\g_salud

sort hogarid
assert _merge==3
drop _merge
sort hogarid
save $LB00\g_total00 , replace

*-----------------------------------------------------------------------------------------
* Valor del uso de los bienes durables
*------------------------------------------------------------------------------------------

* Calcular valor del uso usando valor del bien divido por numero de los a~os que quedan
* La vida expectativa del bien es (2*promedio) por cada tipo
* Si la vida que queda es menos que un a~o o negativo pone 1 a~o para bienes que tienen
* una vida expectativa menos de 10 a~os y 2 por los que tienen vida expectativa mas de 10.
* Es la metodolgia usado por BM (programa equipo.spss) 


use $LB00\equipos00
collapse (mean) vidabien=s8cp03 , by(s8cp00)
replace vidabien = 2* vidabien
sort s8cp00 
save $LB00\vidabien , replace

use $LB00\equipos00
sort s8cp00
merge s8cp00 using $LB00\vidabien
assert _merge==3
drop if s8cp01==2
gen vida_exp = vidabien-s8cp03 
replace vida_exp = 1 if vida_exp < 1 & vidabien < 10
replace vida_exp = 2 if vida_exp < 1 & vidabien >= 10
gen val_dur = s8cp04/vida_exp
collapse (sum) val_dur , by(hogarid)
sort hogarid
save $LB00\g_bienes , replace

use $LB00\g_total00
merge hogarid using $LB00\g_bienes

assert _merge~=2
drop _merge
recode val_dur .=0
sort hogarid
save $LB00\g_total00 , replace


*-----------------------------------------------------------------------------------------
* Gastos de Educacion
*------------------------------------------------------------------------------------------

* Multiplicar gastos mensuales de educacion por 8.5 como en EMNV 1998 (programa educ.sps)

global ed_mult "8.5"

use s5p49 s5p50 s5p51 s5p67b s5p69a s5p69b s5p70b s5p71b s5p72b s5p73b s5p74b s5p75b hogarid using $LB00\poblacionlb00

* Anualizar los que necesitan

replace s5p49 =s5p49 *$ed_mult
replace s5p67b=s5p67b*$ed_mult
replace s5p69a=s5p69a*s5p69b
replace s5p70b=s5p70b*$ed_mult
replace s5p71b=s5p71b*$ed_mult

collapse (sum) s5p49 s5p50 s5p51 s5p67b s5p69a s5p70b s5p71b s5p72b s5p73b s5p74b s5p75b, by (hogarid)
gen educ=s5p49 + s5p50 + s5p51 + s5p67b + s5p69a+ s5p70b+ s5p71b + s5p72b + s5p73b + s5p74b + s5p75b
drop  s5p49 s5p50 s5p51 s5p67b- s5p75b

sort hogarid
save $LB00\g_educ , replace 

use $LB00\g_total00
merge hogarid using $LB00\g_educ

sort hogarid
assert _m==3
drop _merge
sort hogarid
save $LB00\g_total00 , replace

*-----------------------------------------------------------------------------------------
* Gastos de salud maternal
*------------------------------------------------------------------------------------------

use hogarid s7p95b s7p96b s7p99b using $LB00\poblacionlb00
collapse (sum) s7p95b s7p96b s7p99b , by (hogarid)
gen saludm=s7p95b + s7p96b + s7p99b
drop s7p95b s7p96b s7p99b
sort hogarid
save $LB00\g_saludm, replace 

use $LB00\g_total00
merge hogarid using $LB00\g_saludm
assert _merge==3
drop _merge
sort hogarid
save $LB00\g_total00 , replace


*------------------------------------------------------------------------------------------

label data "LdB 2000 : Gastos anuales totales"
rename i09 personas
drop pcfoodus errort alimeu error*

gen total = alim + noalim + agua + basura + electric + luz + fuel + telefono + renta + salud + val_dur + educ + saludm
gen foodshr = alim / total

gen lfood   = ln(alim)
gen lpcfood = ln(pcfood)

gen ltotal = ln(total)
gen pctotal = total / personas 
gen lpctotal = ln(pctotal)

label var total    "Gast anual TOTAL C$"
label var ltotal   "Ln Gast anual TOTAL C$" 
label var pctotal  "Gast anual TOTAL PC C$"
label var lpctotal "Ln Gast anual TOTAL PC C$"
label var lfood    "Ln Gast anual TOTAL comida C$" 
label var lpcfood  "Ln Gast anual TOTAL PC comida C$" 

label var agua      "Gast anual : agua" 
label var basura    "Gast anual : basura" 
label var electric  "Gast anual : electric" 
label var luz       "Gast anual : luz" 
label var fuel      "Gast anual : fuel" 
label var telefono  "Gast anual : telefono" 
label var renta     "Gast anual : renta IMPUTADA" 
label var salud     "Gast anual : salud" 
label var educ      "Gast anual : educ" 
label var saludm    "Gast anual : salud de madre"
label var val_dur   "Gast anual : valor uso bienes IMPUTADOS" 
label var foodshr   "Gast alimenticios / Total" 

order  hogarid personas alim noalim agua basura fuel educ electric luz telefono salud saludm renta val_dur total ltotal pctotal lpctotal foodshr lfood pcfood lpcfood 

format noalim %9.0f ;
format agua   %9.0f ;

compress 
sort hogarid
save $LB00\g_total00 , replace 

g pctotus = pctotal / $EXRATE 
sort pctotus
li hogarid pctotus if pctotus<45, noobs nolab
li hogarid pctotus if pctotus>1500 , noobs nolab 


erase $LB00\g_salud.dta
erase $LB00\g_bienes.dta
erase $LB00\g_educ.dta
erase $LB00\vidabien.dta 
erase $LB00\g_otros.dta 
erase $LB00\g_saludm.dta 
erase $LB00\tmpdigit.dta 

exit
