/***********************************************************************************************/
/* CALCULATION OF FOOD CONSUMPTION IN GRAMS BY FOOD IN 2000					  	      */	
/***********************************************************************************************/                                                            
/* use a semicolon as the command delimiter */
#delimit ;

clear;

set matsize 800;
set memory 100m;

/* open item-level food consumption dataset */
use "$RD00\g_food00";

/****************************************************/
/* Check for errors in 'unit' variable food-by-food */
/* using the list in annex 3 of "Metodologia de     */
/* Construccion del Agregado de Consume, de las     */
/* Lineas de Pobreza y del Agregado de Ingreso en   */
/* Nicaragua" by INEC (see bibliography) with some  */
/* additional codes added on a case-by-case basis.  */
/* The data appendix provides full details.         */
/****************************************************/              

generate error_unit = 1;
replace error_unit = 0 if food==1 & inlist(unit,1,2,16,17,18,48);													/* oatmeal: weight */
replace error_unit = 0 if food==2 & inlist(unit,1,2,3,5);														/* tortilla: weight, quantity */
replace error_unit = 0 if food==3 & inlist(unit,3);															/* nacatamale: quantity */
replace error_unit = 0 if food==4 & inlist(unit,3,7);															/* corn-on-cob: quantity */
replace error_unit = 0 if food==5 & inlist(unit,1);															/* dried corn: weight */
replace error_unit = 0 if food==6 & inlist(unit,1,2,3,8,9,10,11,12);												/* bread: weight, quantity */
replace error_unit = 0 if food==7 & inlist(unit,1,2,3);														/* sweet bread: weight, quantity */
replace error_unit = 0 if food==8 & inlist(unit,1,2,3,13,14,15);													/* crackers: weight, quantity */
replace error_unit = 0 if food==9 & inlist(unit,1);															/* rice: weight */
replace error_unit = 0 if food==10 & inlist(unit,1,2,19,48);													/* pasta: weight */
replace error_unit = 0 if food==11 & inlist(unit,1,2,16,17,18,20,21,22,48);											/* coffee: weight */
replace error_unit = 0 if food==12 & inlist(unit,1);															/* beef: weight */
replace error_unit = 0 if food==13 & inlist(unit,1);															/* pork: weight */
replace error_unit = 0 if food==14 & inlist(unit,1);															/* pork bones: weight */
replace error_unit = 0 if food==15 & inlist(unit,1,3);														/* chicken: weight, quantity */
replace error_unit = 0 if food==16 & inlist(unit,1,3);														/* fish: weight, quantity */
replace error_unit = 0 if food==17 & inlist(unit,1);															/* prawns: weight */
replace error_unit = 0 if food==18 & inlist(unit,2,23,24);														/* sardines: weight */
replace error_unit = 0 if food==19 & inlist(unit,1,2,19,48);													/* hot dogs: quantity */
replace error_unit = 0 if food==20 & inlist(unit,44,45);														/* milk: volume */
replace error_unit = 0 if food==21 & inlist(unit,1,2,35);														/* powdered milk: weight */
replace error_unit = 0 if food==22 & inlist(unit,1,2,3,18,48);													/* cheese: weight, quantity */
replace error_unit = 0 if food==23 & inlist(unit,1,2,18,19,25,44,48);												/* butter: weight, volume */
replace error_unit = 0 if food==24 & inlist(unit,3,6,7);														/* eggs: quantity */
replace error_unit = 0 if food==25 & inlist(unit,37,38,44,45);													/* veg oil: volume */	
replace error_unit = 0 if food==26 & inlist(unit,37,38,44,45);													/* lard: volume */
replace error_unit = 0 if food==27 & inlist(unit,3,7);														/* passion fruit: quantity */
replace error_unit = 0 if food==28 & inlist(unit,3,7);														/* oranges: quantity */
replace error_unit = 0 if food==29 & inlist(unit,3,4,7);														/* apple: quantity */
replace error_unit = 0 if food==30 & inlist(unit,3,7);														/* avocado: quantity */
replace error_unit = 0 if food==31 & inlist(unit,3,7);														/* plantain: quantity */
replace error_unit = 0 if food==32 & inlist(unit,1,3,7,30);														/* white onion: weight, quantity */
replace error_unit = 0 if food==33 & inlist(unit,1,3,7,30);														/* yellow onion: weight, quantity */
replace error_unit = 0 if food==34 & inlist(unit,1,3,7,28,29);													/* garlic: weight, quantity */
replace error_unit = 0 if food==35 & inlist(unit,1,3,7);														/* tomato: weight, quantity */
replace error_unit = 0 if food==36 & inlist(unit,1,3,7);														/* green tomato: weight, quantity */
replace error_unit = 0 if food==37 & inlist(unit,3,4,7);														/* cabbage: quantity */
replace error_unit = 0 if food==38 & inlist(unit,3,7);														/* cucumber: quantity */
replace error_unit = 0 if food==39 & inlist(unit,1,2,3);														/* potatoes: weight, quantity */
replace error_unit = 0 if food==40 & inlist(unit,1,3,7,30);														/* carrots: weight, quantity */
replace error_unit = 0 if food==41 & inlist(unit,1);															/* beans: weight */
replace error_unit = 0 if food==42 & inlist(unit,1,3,31,46);													/* cilantro, celery: weight, quantity */
replace error_unit = 0 if food==43 & inlist(unit,1,26);			 											/* yucca: weight, quantity */
replace error_unit = 0 if food==44 & inlist(unit,1,2);														/* sugar: weight */
replace error_unit = 0 if food==45 & inlist(unit,1,2,3,32);														/* candy: weight, quantity */
replace error_unit = 0 if food==46 & inlist(unit,21,22,33,34,48);													/* jelly: weight */
replace error_unit = 0 if food==47 & inlist(unit,1,2,3,16,17,18,21,22,36,48);											/* condiments: weight, quantity */
replace error_unit = 0 if food==48 & inlist(unit,1,2);														/* salt: weight */
replace error_unit = 0 if food==49 & inlist(unit,18,19,37,38,39,40,41,44,45,48,49); 									/* vinegar: volume */
replace error_unit = 0 if food==50 & inlist(unit,2,3,16,17,18,19,20,21,36,37,38,48,49);									/* ketchup: weight, quantity, volume */
replace error_unit = 0 if food==51 & inlist(unit,2,3,16,17,18,19,20,21,22,36,37,38,44,48);								/* mustard: weight, quantity, volume */
replace error_unit = 0 if food==52 & inlist(unit,3,37,38,39,40,41,42,43,44,45,48,49);									/* canned juice: quantity, volume */
replace error_unit = 0 if food==53 & inlist(unit,37,38,39,40,41,42,43,45,48,49);										/* mineral water: volume */ 
replace error_unit = 0 if food==54 & inlist(unit,37,38,39,40,41,44,45);												/* liquor: volume */
replace error_unit = 0 if food==55 & inlist(unit,37,38,39,40,41,44,45);												/* beer: volume */
replace error_unit = 0 if food==56 & inlist(unit,3,44,45,48); 													/* ice cream: quant, vol */
replace error_unit = 0 if food==57 & inlist(unit,3,7,47);														/* cigarettes: quantity */
replace error_unit = 0 if food==58 & inlist(unit,3,27);														/* prepared food: quantity, value */
replace error_unit = 0 if food==59 & inlist(unit,1,48);														/* veg shortening: weight */
replace error_unit = 0 if food==99 & inlist(unit,27);															/* meals out: value */
 
/*********************************************************************/
/* Summarize error-rate in food unit codes                           				*/
/*********************************************************************/

log using "$RD00\food_units00_log", replace;
/* fraction of food consumption observations with invalid units */
tab error_unit;
log off;

/*********************************************************************/
/* Recode unit data to either counts, grams or liters as appropriate */
/* use conversion codes used by INEC in their SPSS files. Also use   */
/* codes on p. 27 of the basic information document of the 1998 LSMS */
/* survey when required (note I use 2.205lbs per kg so the   	   */
/* the numbers reported below differ slightly from those in          */
/* the 1998 LSMS documentation and the SPSS code)                    */
/*********************************************************************/

/* units-to-counts */
generate counts = 1 if unit==3 & error_unit==0;								/* units */
replace counts = 12 if unit==7 & error_unit==0;								/* a dozen units (e.g., eggs) */
replace counts = 20 if unit==47 & error_unit==0;							/* packet of 20 units (e.g., cigarettes) */


/* weight-to-grams */
g grams = 453.5 if unit ==1 & error_unit==0;								/* pounds into grams */
replace grams = 1 if unit==2 & error_unit==0;								/* grams */
replace grams = 80 if unit==5 & food == 2 & error_unit==0;						/* grams per tortilla (ONLY VALID FOR TORTILLA : food = 2) */
replace grams = 30*62.5 if unit==6 & food==24 & error_unit==0;					/* grams per 30 eggs (ONLY VALID FOR EGGS: food = 24) */
replace grams = 113.4 if unit==8 & inlist(food,6,7) & error_unit==0;				/* grams per loaf of bread (ONLY VALID FOR BREAD: food = 6,7) */
replace grams = 561 if unit==9 & food==6 & error_unit==0;						/* grams per large mould (ONLY VALID FOR BREAD: food = 6) */
replace grams = 292 if unit==10 & food==6 & error_unit==0;						/* grams per small mould (ONLY VALID FOR BREAD: food = 6) */
replace grams = 425 if unit==11 & food==6 & error_unit==0;						/* grams per packet of hamburger buns (ONLY VALID FOR BREAD: food = 6) */
replace grams = 275 if unit==12 & food==6 & error_unit==0;						/* grams per packet of hot dog buns (ONLY VALID FOR BREAD: food = 6) */
replace grams = 272 if unit==13 & food==8 & error_unit==0;						/* grams per large packet of crackers (ONLY VALID FOR CRACKERS: food = 8) */
replace grams = 25 if unit==14 & food==8 & error_unit==0;						/* grams per small packet of crackers (ONLY VALID FOR CRACKERS: food = 8)  */
replace grams = 226.8 if unit==15 & food==8 & error_unit==0;					/* grams per box of crackers (ONLY VALID FOR CRACKERS: food = 8)  */
replace grams = 28.3 if unit==16 & error_unit==0;							/* grams per ounce bag */
replace grams = 56.7 if unit==17 & error_unit==0;							/* grams per two ounce bag */
replace grams = 113.4 if unit==18 & error_unit==0;							/* grams per four ounce bag */
replace grams = 226.8 if unit==19 & error_unit==0;							/* grams per eight ounce bag */
replace grams = 250 if unit==20 & error_unit==0;							/* 250 gram bottle */
replace grams = 150 if unit==21 & error_unit==0;							/* 150 gram bottle */
replace grams = 50 if unit==22 & error_unit==0;								/* 50 gram bottle */
replace grams = 170 if unit==23 & error_unit==0;							/* 170 gram tin of tuna (ONLY VALID FOR SARDINES: food = 18) */
replace grams = 110 if unit==24 & error_unit==0;					 		/* 110 gram tin of tuna (ONLY VALID FOR SARDINES: food = 18) */
replace grams = 113.4 if unit==25 & error_unit==0;							/* grams per four ounce bar */
replace grams = 22675.7 if unit==26 & food==43 & error_unit==0;					/* grams per 50 pound hamaca of yucca/manioc (ONLY VALID FOR YUCCA: food = 43) */
replace grams = 28.3 if unit==28 & food==34 & error_unit==0;					/* grams per head of garlic (ONLY VALID FOR GARLIC: food = 34)*/
replace grams = 283.4 if unit==29 & food==34 & error_unit==0;					/* grams per string of garlic (ONLY VALID FOR GARLIC: food = 34) */
replace grams = 1020.4 if unit==30 & food==40 & error_unit==0; 					/* average of grams per armful of beets and grams per armful of carrots */
															/* (ONLY VALID FOR ONIONS: food = 32, 33) */
replace grams = 680.3 if unit==30 & (food==32 | food==33) & error_unit==0;			/* grams per armful of onions (ONLY VALID FOR ONIONS: food = 32, 33)*/
replace grams = 28.3 if unit==31 & food==42 & error_unit==0;					/* grams per handful of mint/cilantro (ONLY VALID FOR CILANTRO: food = 42) */
replace grams = 133 if unit==32 & food==45 & error_unit==0;						/* grams per bag of sweets (ONLY VALID FOR SWEETS: food = 45) */
replace grams = 283.4 if unit==33 & error_unit==0;							/* grams per ten ounce box */
replace grams = 141.7 if unit==34 & error_unit==0;							/* grams per five ounce box */
replace grams = 400 if unit==35 & error_unit==0;							/* 400 gram jar */
replace grams = 1.5 if unit==36 & error_unit==0;							/* grams per condiment packet (VALID FOR CONDIMENTS: food = 47, 50, 51) */
replace grams = 28.3 if unit==46 & food==42 & error_unit==0;					/* grams per stick (of celery) */
replace grams = 28.3 if unit==48 & error_unit==0;							/* grams per ounce */

/* misc-to-grams */
replace grams = 1476.5 if food==29 & unit==4 & error_unit==0;					/* grams per slice of apple/watermelon */
replace grams = 574.4 if food==37 & unit==4 & error_unit==0;					/* grams per slice of cabbage */

/* volume-to-liters */
g liters = 0.750 if unit==37 & error_unit==0;								/* liters per 750 milliliter bottle */
replace liters = 0.370 if unit==38 & error_unit==0;							/* liters per 370 milliliter bottle */
replace liters = 0.280 if unit==39 & error_unit==0;							/* liters per 280 milliliter bottle */
replace liters = 0.125 if unit==40 & error_unit==0;							/* average liters per 100 - 150 milliliter bottle */
replace liters = 0.355 if unit==41 & error_unit==0;							/* liters per 12 ounce bottle */
replace liters = 0.18 if unit==42 & error_unit==0;							/* average liters per 160 to 200 milliliter can of juice */
replace liters = 0.225 if unit==43 & error_unit==0;							/* average liters per 200 to 250 milliliter can of juice */
replace liters = 3.785 if unit==44 & error_unit==0;							/* liters per gallon */
replace liters = 1 if unit==45 & error_unit==0;								/* liters */
replace liters = 0.0296 if unit==48 & inlist(food,53,56);						/* fluid ounces into liters */

g assigned_counts_grams_liters=1 if count~=. | grams ~=. | liters ~=.;

log on;
/* check to see that all error free units have been coded as counts, grams or liters */
tab assigned_counts_grams_liters if error_unit==0;
tab error_unit;
sum counts grams liters if error_unit==0;
log off;
drop assigned_counts_grams_liters;

/********************************************************************/
/* Recode count and volume values into grams using the conversion   */
/* factors on p. 28 of the basic information document of the        */
/* 1998 LSMS (note these are food specific) and/or the INEC code    */
/********************************************************************/

/* counts-to-grams */
replace grams = 80*counts if food == 2 & counts ~= . & error_unit==0;				/* recode quantities of tortilla into grams */
replace grams = 453.5*counts if food == 3 & counts ~= . & error_unit==0;			/* recode quantities of nacatamale into grams */
replace grams = 170*counts if food == 4 & counts ~= . & error_unit==0;				/* recode quantities of corn on the cob into grams */
replace grams = 113.4*counts if food == 6 & counts ~= . & error_unit==0;			/* recode quantities of simple bread into grams */
replace grams = 170.1*counts if food == 7 & counts ~= . & error_unit==0;			/* recode quantities of sweet bread into grams */
replace grams = 25*counts if food == 8 & counts ~= . & error_unit==0;				/* recode quantities of crackers into grams */
replace grams = 1816*counts if food == 15 & counts ~= . & error_unit==0;			/* recode quantities of chicken into grams */
replace grams = 392.6*counts if food == 16 & counts ~= . & error_unit==0;			/* recode quantities of fish into grams */
replace grams = 324.0*counts if food == 22 & counts ~= . & error_unit==0;			/* recode quantities of cheese into grams */
replace grams = 62.5*counts if food == 24 & counts ~= . & error_unit==0;			/* recode quantities of egg into grams */
replace grams = 113.9*counts if food == 27 & counts ~= . & error_unit==0;			/* recode quantities of maracuya into grams */
replace grams = 128.7*counts if food == 28 & counts ~= . & error_unit==0;			/* recode quantities of lemons/oranges into grams */
replace grams = 2952.9*counts if food == 29 & counts ~= . & error_unit==0;			/* recode quantities of apples/watermelons into grams */
replace grams = ((294.2+377.3)/2)*counts if food == 30 & counts ~= . & error_unit==0; 	/* recode quantities of avocado/chayote into grams */
replace grams = 226.8*counts if food == 31 & counts ~= . & error_unit==0;			/* recode quantities of plantains into grams */
replace grams = 113.4*counts if food == 32 & counts ~= . & error_unit==0;			/* recode quantities of white onions into grams */
replace grams = 113.4*counts if food == 33 & counts ~= . & error_unit==0;			/* recode quantities of yellow onions into grams */
replace grams = 28.3*counts if food == 34 & counts ~= . & error_unit==0;			/* recode quantities of garlic into grams */
replace grams = 28.3*counts if food == 35 & counts ~= . & error_unit==0;			/* recode quantities of chiltoma into grams */
replace grams = 85.0*counts if food == 36 & counts ~= . & error_unit==0;			/* recode quantities of tomato into grams */
replace grams = 1395.1*counts if food == 37 & counts ~= . & error_unit==0;			/* recode quantities of lettuce/cabbage into grams */
replace grams = 197.3*counts if food == 38 & counts ~= . & error_unit==0;			/* recode quantities of cucumber into grams */
replace grams = 85.0*counts if food == 39 & counts ~= . & error_unit==0;			/* recode quantities of potatoe into grams */
replace grams = 170.1*counts if food == 40 & counts ~= . & error_unit==0;			/* recode quantities of carrot/beet into grams */
replace grams = 28.3*counts if food == 42 & counts ~= . & error_unit==0;			/* recode quantities of cilantro into grams */
replace grams = 226.8*counts if food == 43 & counts ~= . & error_unit==0;			/* recode quantities of yucca into grams */
replace grams = (133/30)*counts if food == 45 & counts ~= . & error_unit==0; 			/* recode quantities of sweets into grams */
replace grams = 1.5*counts if food == 47 & counts ~= . & error_unit==0; 			/* recode quantities of condiments into grams */
replace grams = 93.3*counts if food == 50 & counts ~= . & error_unit==0; 			/* recode quantities of ketchup into grams */
replace grams = 113.4*counts if food == 51 & counts ~= . & error_unit==0; 			/* recode quantities of mustard into grams */
replace grams = 1000*0.340*counts if food == 52 & counts ~= . & error_unit==0;		/* recode quantities of canned juice into grams */
replace grams = 1000*0.340*counts if food == 55 & counts ~= . & error_unit==0;		/* recode quantities of beer into grams */
replace grams = 113.4*counts if food == 56 & counts ~= . & error_unit==0;			/* recode quantities of ice cream (ice cream cones/snacks) into grams */

log on;
/* check to see that all counts have been converted into grams (except cigarettes, and prepared foods) */
sum counts if error_unit==0;
sum grams if counts~=. & error_unit==0;
tab food if counts~=. & grams==. & error_unit==0;
log off;

/* liters-to-grams */
replace grams = 1029.5*liters if food == 20 & liters ~= . & error_unit==0;			/* recode liters of milk into grams */
replace grams = ((32*4)/3.785)*28.3*liters if unit==44 & food==23 & error_unit==0;		/* grams per gallon of butter */				
replace grams = 907*liters if food == 25 & liters ~= . & error_unit==0;				/* recode liters of vegtable oil into grams */
replace grams = 850.3*liters if food == 26 & liters ~= . & error_unit==0;			/* recode liters of pork lard into grams */
replace grams = 1000*liters if food == 49 & liters ~= . & error_unit==0;			/* recode liters of vinegar into grams */
replace grams = 958.6*liters if food == 50 & liters ~= . & error_unit==0;			/* recode liters of ketchup into grams */
replace grams = 958.6*liters if food == 51 & liters ~= . & error_unit==0;			/* recode liters of mustard into grams */
replace grams = 1000*liters if food == 52 & liters ~= . & error_unit==0;			/* recode liters of canned juice into grams */
replace grams = 1000*liters if food == 53 & liters ~= . & error_unit==0;			/* recode liters of water into grams */
replace grams = 943.3*liters if food == 54 & liters ~= . & error_unit==0;			/* recode liters of liquor into grams */
replace grams = 1000*liters if food == 55 & liters ~= . & error_unit==0;			/* recode liters of beer into grams */
replace grams = 48.3*liters if food == 56 & liters ~= . & error_unit==0;			/* recode liters of ice cream into grams */

log on;
/* check to see that all liters have been converted into grams */
sum liters if error_unit==0;
sum grams if liters~=. & error_unit==0;
tab food if liters~=. & grams==. & error_unit==0;

/********************************************************************/
/* summarize conversion of all food purchase units into grams;      */
/* (all food records with valid units have been converted into grams*/
/* except for those corresponding to meals out and cigarettes)      */
/********************************************************************/

tab error_unit;
sum grams if error_unit==0;
tab food if grams==. & error_unit==0;

/* no foods with invalid units should have quantities converted into grams */
tab food if grams==. & error_unit==1;
log off;
log close;

/**************************************************************************/
/* multiply grams by number of units bought to get total amount purchased */
/* (also convert to 100g units)							  */	
/**************************************************************************/
replace grams = grams*quantity/100;
save "$RD00\g_grams00", replace;
