/***********************************************************************************************/
/* CALORIE DEMAND APPLICATION IN PANEL APE PAPER                					           */
/* Bryan S. Graham & James L. Powell							     						   */
/* UC - Berkeley, Department of Economics									     			   */
/* Spring 2011													     						   */		
/***********************************************************************************************/ 

/***********************************************************************************************/
/* This is the base do file which processes the IFPRI (2005) public release RPS evaluation     */
/* dataset and produces the estimation dataset used in our paper. The consumption aggregates,  */
/* calorie availability and price indices are generated by the various Do files called below.  */
/* To replicate our manipulations extract the replicate_data_extraction zip archive. Replace   */
/* test in the directory pointers below upto "...Panel_APE_11Spring\" with the appropriate     */
/* extraction directory.                                                                       */
/***********************************************************************************************/ 

/***********************************************************************************************/
/* CALLED DO FILES AND DESCRIPTIONS                                                            */
/* demographics_xx 		- forms basic household demographic variables (in year xx = 00, 01, 02)*/
/* consumption_xx	    - forms household consumption aggregate                                */
/* calories_xx          - forms household calorie availability aggregate                       */
/* protein_xx           - forms household protein availability aggregate (not used in paper)   */  
/* iron_xx				- forms household iron availability aggregate (not used in paper)      */ 
/* zinc_xx				- forms household zinc availability aggregate (not used in paper)      */ 
/* prices_xx            - forms household-specific price index                                 */
/***********************************************************************************************/
                                                             
/* use a semicolon as the command delimiter */
#delimit ;

clear;
clear matrix;
clear mata;

set matsize 800;
set memory 100m;

/* DEFINE VARIOUS ROOT DIRECTORIES AS A GLOBAL VARIABLES */

global DO00 "C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData\Nicaragua_IFPRI_Data\baseline00\programs";
global DO01 "C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData\Nicaragua_IFPRI_Data\baseline01\programs";
global DO02 "C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData\Nicaragua_IFPRI_Data\baseline02\programs";
global RD00 "C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData\Nicaragua_IFPRI_Data\baseline00\data\stata7";
global RD01 "C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData\Nicaragua_IFPRI_Data\baseline01\data\stata7";
global RD02 "C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData\Nicaragua_IFPRI_Data\baseline02\data\stata7";
global BASE "C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData";
global TC 	"C:\Documents and Settings\bsg1\My Documents\BSG_WORK_19W4th\Research\Panel\Panel_APE_11Spring\PanelDataCodeAndData\Nicaragua_IFPRI_Data\ToC\data\stata7";

use "$TC\toccomcens.dta", clear;
sort comcens;
save "$TC\toccomcens", replace;

do "$DO01\demographics_01";
do "$DO01\consumption_01";
do "$DO01\calories_01";
do "$DO01\protein_01";
do "$DO01\iron_01";
do "$DO01\zinc_01";
do "$DO01\prices_01";

do "$DO00\demographics_00";
do "$DO00\consumption_00";
do "$DO00\food_in_grams_00";
do "$DO00\calories_00";
do "$DO00\protein_00";
do "$DO00\iron_00";
do "$DO00\zinc_00";
do "$DO00\prices_00";

do "$DO02\demographics_02";
do "$DO02\consumption_02";
do "$DO02\calories_02";
do "$DO02\protein_02";
do "$DO02\iron_02";
do "$DO02\zinc_02";
do "$DO02\prices_02";

/* Organize Calendar Year 2000 Files */
use "$RD00\g_cal_exp_clean00", clear;
sort hogarid;

merge hogarid using "$RD00\priceindex00.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD00\g_cal_exp_clean00", replace;

merge hogarid using "$RD00\g_pro_exp_clean00.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD00\g_cal_exp_clean00", replace;

merge hogarid using "$RD00\g_iro_exp_clean00.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD00\g_cal_exp_clean00", replace;

merge hogarid using "$RD00\g_znc_exp_clean00.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD00\g_cal_exp_clean00", replace;

/* Organize Calendar Year 2001 Files */
use "$RD01\g_cal_exp_clean01", clear;
sort hogarid;

merge hogarid using "$RD01\priceindex01.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD01\g_cal_exp_clean01", replace;

merge hogarid using "$RD01\g_pro_exp_clean01.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD01\g_cal_exp_clean01", replace;

merge hogarid using "$RD01\g_iro_exp_clean01.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD01\g_cal_exp_clean01", replace;

merge hogarid using "$RD01\g_znc_exp_clean01.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD01\g_cal_exp_clean01", replace;

/* Organize Calendar Year 2002 Files */
use "$RD02\g_cal_exp_clean02", clear;
sort hogarid;

merge hogarid using "$RD02\priceindex02.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD02\g_cal_exp_clean02", replace;

merge hogarid using "$RD02\g_pro_exp_clean02.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD02\g_cal_exp_clean02", replace;

merge hogarid using "$RD02\g_iro_exp_clean02.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD02\g_cal_exp_clean02", replace;

merge hogarid using "$RD02\g_znc_exp_clean02.dta";
tab _m;
drop _m;
sort hogarid;
save "$RD02\g_cal_exp_clean02", replace;

/* Merge All Three Years of Data to Form a Panel */
use "$RD00\g_cal_exp_clean00", clear;
sort hogarid;
append using "$RD01\g_cal_exp_clean01";
sort hogarid;
append using "$RD02\g_cal_exp_clean02";

/************************************************************************************/
/* Generate additional variables										            */
/************************************************************************************/		

/* generate food budget and calorie share variables */
g cereal_eshare		= cereal_exp/food_exp;
g root_eshare 		= root_exp/food_exp;
g pulse_eshare 		= pulse_exp/food_exp;
g veggie_eshare		= veggie_exp/food_exp;
g fruit_eshare 		= fruit_exp/food_exp;
g meat_eshare 		= meat_exp/food_exp;
g dairy_eshare 		= dairy_exp/food_exp;
g oil_eshare 		= oil_exp/food_exp;
g beverage_eshare 	= beverage_exp/food_exp;
g meal_eshare 		= meal_exp/food_exp;
g misc_eshare 		= misc_exp/food_exp;
g other_eshare 		= other_exp/food_exp;
g bmmo_eshare 		= bmmo_exp/food_exp;
g staple_eshare    	=(cereal_exp + root_exp + pulse_exp)/food_exp;

g cereal_cshare		= cereal_calories/calories;
g root_cshare 		= root_calories/calories;
g pulse_cshare 		= pulse_calories/calories;
g veggie_cshare		= veggie_calories/calories;
g fruit_cshare 		= fruit_calories/calories;
g meat_cshare 		= meat_calories/calories;
g dairy_cshare 		= dairy_calories/calories;
g oil_cshare 		= oil_calories/calories;
g beverage_cshare 	= beverage_calories/calories;
g meal_cshare 		= meal_calories/calories;
g misc_cshare 		= misc_calories/calories;
g other_cshare 		= other_calories/calories;
g bmmo_cshare 		= bmmo_calories/calories;
g staple_cshare    	=(cereal_calories + root_calories + pulse_calories)/calories;

g real_exp_ame 			= (total_exp_b/paasche_b)/adult_male_equivalent;
replace calories_ame 	= calories/adult_male_equivalent;

g real_exp_pc 			= (total_exp_b/paasche_b)/member;
g log_real_exp_pc 		= log(real_exp_pc);

g calories_pc 			= calories/member;
g log_calories_pc 		= log(calories_pc);

replace protein_ame 	= protein/adult_male_equivalent;
g protein_pc 			= protein/member;
g log_protein_pc 		= log(protein_pc);

replace iron_ame 		= iron/adult_male_equivalent;
g iron_pc 				= iron/member;
g log_iron_pc 			= log(iron_pc);

replace zinc_ame 		= zinc/adult_male_equivalent;
g zinc_pc 				= zinc/member;
g log_zinc_pc 			= log(zinc_pc);

g log_real_exp			= log(total_exp_b/paasche_b);
g log_calories			= log(calories);

keep 	comcens hogarid year 
		food_share food_share_b total_exp total_exp_b real_exp_ame calories_ame real_exp_pc calories_pc paasche_b	
        caloric_requirement adult_male_equivalent member
		log_calories log_calories_pc log_real_exp log_real_exp_pc
		age_0t1g age_0t1b age_1t5g age_1t5b age_5t9g age_5t9b age_9t14g age_9t14b age_14t18g age_14t18b 
		age_18t30g age_18t30b age_30t60g age_30t60b age_60g age_60b
		food_exp 
		cereal_eshare root_eshare pulse_eshare veggie_eshare fruit_eshare meat_eshare dairy_eshare oil_eshare 
		bmmo_eshare beverage_eshare meal_eshare misc_eshare other_eshare staple_eshare
		calories
		cereal_cshare root_cshare pulse_cshare veggie_cshare fruit_cshare meat_cshare dairy_cshare oil_cshare 
		bmmo_cshare beverage_cshare meal_cshare misc_cshare other_cshare staple_cshare
		calorie_price
		cereal_price root_price pulse_price veggie_price fruit_price meat_price dairy_price oil_price 
		bmmo_price beverage_price meal_price misc_price other_price
		protein_price protein_ame protein_pc log_protein_pc
		iron_price iron_ame iron_pc log_iron_pc
		zinc_price zinc_ame zinc_pc log_zinc_pc;


sort comcens;
merge comcens using "$TC/toccomcens.dta";
tab _m;
drop _m;
rename grupo RPS;
drop indice priorid;

/************************************************************************************/
/* Estimate pooled OLS and within-OLS models             						    */
/************************************************************************************/		

egen household = group(hogarid);
bys household: egen balanced = sum((log_calories>0)*(log_calories~=.));
replace balanced = 0 if balanced < 3;
replace balanced = 1 if balanced ==3;
drop if balanced~=1;

egen village = group(comcens);

g yr2001 = (year==2001);
g yr2002 = (year==2002);

g yr2001_X_lre = yr2001*log_real_exp_pc;
g yr2002_X_lre = yr2002*log_real_exp_pc;

g i_real_exp_pc = 1/real_exp_pc;
g yr2001_X_ire = yr2001*i_real_exp_pc;
g yr2002_X_ire = yr2002*i_real_exp_pc;

log using "$BASE/summary", replace;

/************************************************************************************/
/* PARAMETRIC CALORIE ANALYSIS				             						    */
/************************************************************************************/		

/*****************************************************************************************/
/* POOLED OLS (w/ village-specific intercepts)  				                         */					
/*****************************************************************************************/

/* Linear models */
areg   	log_calories_pc log_real_exp_pc yr2001  yr2002 yr2001_X_lre yr2002_X_lre, absorb(comcens) cluster(comcens);

test   	yr2001 yr2002 yr2001_X_lre yr2002_X_lre;
test   	yr2001 yr2002;
test   	yr2001_X_lre yr2002_X_lre;

lincom 	log_real_exp_pc;
lincom 	log_real_exp_pc + yr2001_X_lre;
lincom 	log_real_exp_pc + yr2002_X_lre;

/* Nonlinear models (full time effects) */
areg 	log_calories_pc log_real_exp_pc i_real_exp_pc yr2001  yr2002 yr2001_X_lre yr2002_X_lre yr2001_X_ire yr2002_X_ire, absorb(comcens) cluster(comcens);

test  	yr2001 yr2002 yr2001_X_lre yr2002_X_lre yr2001_X_ire yr2002_X_ire;
test    yr2001 yr2002;
test  	yr2001_X_lre yr2002_X_lre yr2001_X_ire yr2002_X_ire;

margins if year==2000, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);
margins if year==2001, expression(_b[log_real_exp_pc]+_b[yr2001_X_lre] - (_b[i_real_exp_pc]+_b[yr2001_X_ire])*i_real_exp_pc);
margins if year==2002, expression(_b[log_real_exp_pc]+_b[yr2002_X_lre] - (_b[i_real_exp_pc]+_b[yr2002_X_ire])*i_real_exp_pc);

/* Nonlinear models (intercept shifts only) */
areg 	log_calories_pc log_real_exp_pc i_real_exp_pc yr2001  yr2002 , absorb(comcens) cluster(comcens);

test    yr2001 yr2002;

margins if year==2000, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);
margins if year==2001, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);
margins if year==2002, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);


/*****************************************************************************************/
/* FE OLS													   	                         */					
/*****************************************************************************************/

/* Linear models */
areg 	log_calories_pc log_real_exp_pc yr2001  yr2002 yr2001_X_lre yr2002_X_lre, absorb(household) cluster(comcens);

test   	yr2001 yr2002 yr2001_X_lre yr2002_X_lre;
test   	yr2001 yr2002;
test   	yr2001_X_lre yr2002_X_lre;

lincom log_real_exp_pc;
lincom log_real_exp_pc + yr2001_X_lre;
lincom log_real_exp_pc + yr2002_X_lre;


/* Nonlinear models (full time effects) */
areg 	log_calories_pc log_real_exp_pc i_real_exp_pc yr2001  yr2002 yr2001_X_lre yr2002_X_lre yr2001_X_ire yr2002_X_ire, absorb(household) cluster(comcens);

test  	yr2001 yr2002 yr2001_X_lre yr2002_X_lre yr2001_X_ire yr2002_X_ire;
test    yr2001 yr2002;
test  	yr2001_X_lre yr2002_X_lre yr2001_X_ire yr2002_X_ire;

margins if year==2000, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);
margins if year==2001, expression(_b[log_real_exp_pc]+_b[yr2001_X_lre] - (_b[i_real_exp_pc]+_b[yr2001_X_ire])*i_real_exp_pc);
margins if year==2002, expression(_b[log_real_exp_pc]+_b[yr2002_X_lre] - (_b[i_real_exp_pc]+_b[yr2002_X_ire])*i_real_exp_pc);

/* Nonlinear models (intercept shifts only) */
areg 	log_calories_pc log_real_exp_pc i_real_exp_pc yr2001  yr2002, absorb(household) cluster(comcens);

test    yr2001 yr2002;

margins if year==2000, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);
margins if year==2001, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);
margins if year==2002, expression(_b[log_real_exp_pc] - _b[i_real_exp_pc]*i_real_exp_pc);

log off;
drop yr2001  yr2002  yr2001_X_lre  yr2002_X_lre yr2001_X_ire  yr2002_X_ire i_real_exp_pc household village;

/*****************************************************************************************/
/* SUMMARY STATISTICS AND DATA EXPORT   					   	                                   */					
/*****************************************************************************************/

/* Transform data to wide format */
reshape wide 
	food_share food_share_b total_exp total_exp_b paasche_b real_exp_ame real_exp_pc calories_ame calories_pc 	
    caloric_requirement adult_male_equivalent member	
	log_calories log_calories_pc log_real_exp log_real_exp_pc
	age_0t1g age_0t1b age_1t5g age_1t5b age_5t9g age_5t9b age_9t14g age_9t14b age_14t18g age_14t18b 
	age_18t30g age_18t30b age_30t60g age_30t60b age_60g age_60b
	food_exp 
	cereal_eshare root_eshare pulse_eshare veggie_eshare fruit_eshare meat_eshare dairy_eshare oil_eshare 
	bmmo_eshare beverage_eshare meal_eshare misc_eshare other_eshare staple_eshare
	calories
	cereal_cshare root_cshare pulse_cshare veggie_cshare fruit_cshare meat_cshare dairy_cshare oil_cshare 
	bmmo_cshare beverage_cshare meal_cshare misc_cshare other_cshare staple_cshare
	calorie_price
	cereal_price root_price pulse_price veggie_price fruit_price meat_price dairy_price oil_price 
	bmmo_price beverage_price meal_price misc_price other_price comcens
	protein_ame protein_pc protein_price log_protein_pc
	iron_ame iron_pc iron_price log_iron_pc
	zinc_ame zinc_pc zinc_price log_zinc_pc, i(hogarid) j(year);

rename log_calories2000 Y0tc;
rename log_calories2001 Y1tc;
rename log_calories2002 Y2tc;

rename log_calories_pc2000 Y0;
rename log_calories_pc2001 Y1;
rename log_calories_pc2002 Y2;

rename log_protein_pc2000 Y0p;
rename log_protein_pc2001 Y1p;
rename log_protein_pc2002 Y2p;

rename log_iron_pc2000 Y0i;
rename log_iron_pc2001 Y1i;
rename log_iron_pc2002 Y2i;

rename log_zinc_pc2000 Y0z;
rename log_zinc_pc2001 Y1z;
rename log_zinc_pc2002 Y2z;

rename log_real_exp2000 X0te;
rename log_real_exp2001 X1te;
rename log_real_exp2002 X2te;

rename log_real_exp_pc2000 X0;
rename log_real_exp_pc2001 X1;
rename log_real_exp_pc2002 X2;

keep if Y0~=. & Y1~=. & Y2~=. & X0~=. & X1~=. & X2~=.;

g avg_real_exp_ame = (real_exp_ame2000+real_exp_ame2001+real_exp_ame2002)/3;
g hungry00 =(caloric_requirement2000>calories2000); 
g hungry01 =(caloric_requirement2001>calories2001); 
g hungry02 =(caloric_requirement2002>calories2002);

_pctile avg_real_exp_ame, nq(4);
scalar c25 = r(r1);
scalar c50 = r(r3);
scalar c75 = r(r3);

egen household = group(hogarid);
egen village = group(comcens2001);

log on;

/* Compare `stayers' with `movers' using 2001 and 2002 waves only */
/* (use bandwidth of 0.023039 as in preferred empirical results)  */
g D = X2-X1;
g stayer = (abs(D)<=0.023039);
g nearstayer = (abs(D)>0.023039)*(abs(D)<=(3/2)*0.023039);
reg stayer Y1 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_0t1g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_0t1b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_1t5g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_1t5b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_5t9g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_5t9b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_9t14g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_9t14b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_14t18g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_14t18b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_18t30g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_18t30b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_30t60g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_30t60b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_60g2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_60b2001 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_0t1g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_0t1b2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_1t5g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_1t5b2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_5t9g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_5t9b2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_9t14g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_9t14b2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_14t18g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_14t18b2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_18t30g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_18t30b2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_30t60g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_30t60b2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_60g2002 if stayer == 1 | nearstayer == 1, cluster(village);
reg stayer age_60b2002 if stayer == 1 | nearstayer == 1, cluster(village);

/* Number of households with less calories than recommended by WHO */
sum hungry00 hungry01 hungry02;
sum hungry00 hungry01 hungry02 if avg_real_exp_ame<=c25;
sum hungry00 hungry01 hungry02 if avg_real_exp_ame>c75;

/* Household food budget 2000 */
tabstat	real_exp_ame2000 real_exp_pc2000 food_share2000 
		cereal_eshare2000 root_eshare2000 pulse_eshare2000 veggie_eshare2000 fruit_eshare2000 meat_eshare2000 dairy_eshare2000 oil_eshare2000 
		bmmo_eshare2000 staple_eshare2000, statistics (count mean median);	
tabstat	real_exp_ame2000 real_exp_pc2000 food_share2000 
		cereal_eshare2000 root_eshare2000 pulse_eshare2000 veggie_eshare2000 fruit_eshare2000 meat_eshare2000 dairy_eshare2000 oil_eshare2000 
		bmmo_eshare2000 staple_eshare2000 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	real_exp_ame2000 real_exp_pc2000 food_share2000 
		cereal_eshare2000 root_eshare2000 pulse_eshare2000 veggie_eshare2000 fruit_eshare2000 meat_eshare2000 dairy_eshare2000 oil_eshare2000 
		bmmo_eshare2000 staple_eshare2000 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household food budget 2001 */
tabstat	real_exp_ame2001 real_exp_pc2001 food_share2001 
		cereal_eshare2001 root_eshare2001 pulse_eshare2001 veggie_eshare2001 fruit_eshare2001 meat_eshare2001 dairy_eshare2001 oil_eshare2001 
		bmmo_eshare2001 staple_eshare2001, statistics (count mean median);	
tabstat	real_exp_ame2001 real_exp_pc2001 food_share2001 
		cereal_eshare2001 root_eshare2001 pulse_eshare2001 veggie_eshare2001 fruit_eshare2001 meat_eshare2001 dairy_eshare2001 oil_eshare2001 
		bmmo_eshare2001 staple_eshare2001 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	real_exp_ame2001 real_exp_pc2001 food_share2001 
		cereal_eshare2001 root_eshare2001 pulse_eshare2001 veggie_eshare2001 fruit_eshare2001 meat_eshare2001 dairy_eshare2001 oil_eshare2001 
		bmmo_eshare2001 staple_eshare2001 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household food budget 2002 */
tabstat	real_exp_ame2002 real_exp_pc2002 food_share2002 
		cereal_eshare2002 root_eshare2002 pulse_eshare2002 veggie_eshare2002 fruit_eshare2002 meat_eshare2002 dairy_eshare2002 oil_eshare2002 
		bmmo_eshare2002 staple_eshare2002, statistics (count mean median);
tabstat	real_exp_ame2002 real_exp_pc2002 food_share2002 
		cereal_eshare2002 root_eshare2002 pulse_eshare2002 veggie_eshare2002 fruit_eshare2002 meat_eshare2002 dairy_eshare2002 oil_eshare2002 
		bmmo_eshare2002 staple_eshare2002 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	real_exp_ame2002 real_exp_pc2002 food_share2002 
		cereal_eshare2002 root_eshare2002 pulse_eshare2002 veggie_eshare2002 fruit_eshare2002 meat_eshare2002 dairy_eshare2002 oil_eshare2002 
		bmmo_eshare2002 staple_eshare2002 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household calorie breakdown 2000 */
tabstat	calories_ame2000 calories_pc2000
		cereal_cshare2000 root_cshare2000 pulse_cshare2000 veggie_cshare2000 fruit_cshare2000 meat_cshare2000 dairy_cshare2000 oil_cshare2000 
		bmmo_cshare2000 staple_cshare2000, statistics (count mean median);
tabstat	calories_ame2000 calories_pc2000
		cereal_cshare2000 root_cshare2000 pulse_cshare2000 veggie_cshare2000 fruit_cshare2000 meat_cshare2000 dairy_cshare2000 oil_cshare2000 
		bmmo_cshare2000 staple_cshare2000 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	calories_ame2000 calories_pc2000
		cereal_cshare2000 root_cshare2000 pulse_cshare2000 veggie_cshare2000 fruit_cshare2000 meat_cshare2000 dairy_cshare2000 oil_cshare2000 
		bmmo_cshare2000 staple_cshare2000 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household calorie breakdown 2001 */
tabstat	calories_ame2001 calories_pc2001
		cereal_cshare2001 root_cshare2001 pulse_cshare2001 veggie_cshare2001 fruit_cshare2001 meat_cshare2001 dairy_cshare2001 oil_cshare2001 
		bmmo_cshare2001 staple_cshare2001, statistics (count mean median);
tabstat	calories_ame2001 calories_pc2001
		cereal_cshare2001 root_cshare2001 pulse_cshare2001 veggie_cshare2001 fruit_cshare2001 meat_cshare2001 dairy_cshare2001 oil_cshare2001 
		bmmo_cshare2001 staple_cshare2001 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	calories_ame2001 calories_pc2001
		cereal_cshare2001 root_cshare2001 pulse_cshare2001 veggie_cshare2001 fruit_cshare2001 meat_cshare2001 dairy_cshare2001 oil_cshare2001 
		bmmo_cshare2001 staple_cshare2001 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household calorie breakdown 2002 */
tabstat	calories_ame2002 calories_pc2002
		cereal_cshare2002 root_cshare2002 pulse_cshare2002 veggie_cshare2002 fruit_cshare2002 meat_cshare2002 dairy_cshare2002 oil_cshare2002 
		bmmo_cshare2002 staple_cshare2002, statistics (count mean median);
tabstat	calories_ame2002 calories_pc2002
		cereal_cshare2002 root_cshare2002 pulse_cshare2002 veggie_cshare2002 fruit_cshare2002 meat_cshare2002 dairy_cshare2002 oil_cshare2002 
		bmmo_cshare2002 staple_cshare2002 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	calories_ame2002 calories_pc2002
		cereal_cshare2002 root_cshare2002 pulse_cshare2002 veggie_cshare2002 fruit_cshare2002 meat_cshare2002 dairy_cshare2002 oil_cshare2002 
		bmmo_cshare2002 staple_cshare2002 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household calorie price 2000 */
tabstat	calorie_price2000
		cereal_price2000 root_price2000 pulse_price2000 veggie_price2000 fruit_price2000 meat_price2000 dairy_price2000 oil_price2000 
		bmmo_price2000, statistics (count mean median);
tabstat	calorie_price2000
		cereal_price2000 root_price2000 pulse_price2000 veggie_price2000 fruit_price2000 meat_price2000 dairy_price2000 oil_price2000 
		bmmo_price2000 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	calorie_price2000
		cereal_price2000 root_price2000 pulse_price2000 veggie_price2000 fruit_price2000 meat_price2000 dairy_price2000 oil_price2000 
		bmmo_price2000 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household calorie price 2001 */
tabstat	calorie_price2001
		cereal_price2001 root_price2001 pulse_price2001 veggie_price2001 fruit_price2001 meat_price2001 dairy_price2001 oil_price2001 
		bmmo_price2001, statistics (count mean median);
tabstat	calorie_price2001
		cereal_price2001 root_price2001 pulse_price2001 veggie_price2001 fruit_price2001 meat_price2001 dairy_price2001 oil_price2001 
		bmmo_price2001 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	calorie_price2001
		cereal_price2001 root_price2001 pulse_price2001 veggie_price2001 fruit_price2001 meat_price2001 dairy_price2001 oil_price2001 
		bmmo_price2001 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household calorie price 2002 */
tabstat calorie_price2002
		cereal_price2002 root_price2002 pulse_price2002 veggie_price2002 fruit_price2002 meat_price2002 dairy_price2002 oil_price2002 
		bmmo_price2002, statistics (count mean median);
tabstat calorie_price2002
		cereal_price2002 root_price2002 pulse_price2002 veggie_price2002 fruit_price2002 meat_price2002 dairy_price2002 oil_price2002 
		bmmo_price2002 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	calorie_price2002
		cereal_price2002 root_price2002 pulse_price2002 veggie_price2002 fruit_price2002 meat_price2002 dairy_price2002 oil_price2002 
		bmmo_price2002 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household other nutrient data 2000 */
tabstat	protein_ame2000 protein_pc2000 protein_price2000
		iron_ame2000 iron_pc2000 iron_price2000
		zinc_ame2000 zinc_pc2000 zinc_price2000, statistics (count mean median);
tabstat	protein_ame2000 protein_pc2000 protein_price2000
		iron_ame2000 iron_pc2000 iron_price2000
		zinc_ame2000 zinc_pc2000 zinc_price2000 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	protein_ame2000 protein_pc2000 protein_price2000
		iron_ame2000 iron_pc2000 iron_price2000
		zinc_ame2000 zinc_pc2000 zinc_price2000 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household other nutrient data 2001 */
tabstat	protein_ame2001 protein_pc2001 protein_price2001
		iron_ame2001 iron_pc2001 iron_price2001
		zinc_ame2001 zinc_pc2001 zinc_price2001, statistics (count mean median);
tabstat	protein_ame2001 protein_pc2001 protein_price2001
		iron_ame2001 iron_pc2001 iron_price2001
		zinc_ame2001 zinc_pc2001 zinc_price2001 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	protein_ame2001 protein_pc2001 protein_price2001
		iron_ame2001 iron_pc2001 iron_price2001
		zinc_ame2001 zinc_pc2001 zinc_price2001 if avg_real_exp_ame>c75, statistics (count mean median);

/* Household other nutrient data 2002 */
tabstat	protein_ame2002 protein_pc2002 protein_price2002
		iron_ame2002 iron_pc2002 iron_price2002
		zinc_ame2002 zinc_pc2002 zinc_price2002, statistics (count mean median);
tabstat	protein_ame2002 protein_pc2002 protein_price2002
		iron_ame2002 iron_pc2002 iron_price2002
		zinc_ame2002 zinc_pc2002 zinc_price2002 if avg_real_exp_ame<=c25, statistics (count mean median);
tabstat	protein_ame2002 protein_pc2002 protein_price2002
		iron_ame2002 iron_pc2002 iron_price2002
		zinc_ame2002 zinc_pc2002 zinc_price2002 if avg_real_exp_ame>c75, statistics (count mean median);

log close;


/* outsheet Graham and Powell (2009) estimation sample for analysis in MATLAB */
outsheet 	Y0tc Y1tc Y2tc Y0 Y1 Y2 Y0p Y1p Y2p Y0i Y1i Y2i Y0z Y1z Y2z X0te X1te X2te X0 X1 X2 RPS household village 
			age_0t1g2000 age_0t1b2000 age_1t5g2000 age_1t5b2000 age_5t9g2000 age_5t9b2000 age_9t14g2000 age_9t14b2000 age_14t18g2000 
			age_14t18b2000 age_18t30g2000 age_18t30b2000 age_30t60g2000 age_30t60b2000 age_60g2000 age_60b2000 
			age_0t1g2001 age_0t1b2001 age_1t5g2001 age_1t5b2001 age_5t9g2001 age_5t9b2001 age_9t14g2001 age_9t14b2001 age_14t18g2001 
			age_14t18b2001 age_18t30g2001 age_18t30b2001 age_30t60g2001 age_30t60b2001 age_60g2001 age_60b2001 
			age_0t1g2002 age_0t1b2002 age_1t5g2002 age_1t5b2002 age_5t9g2002 age_5t9b2002 age_9t14g2002 age_9t14b2002 age_14t18g2002 
			age_14t18b2002 age_18t30g2002 age_18t30b2002 age_30t60g2002 age_30t60b2002 age_60g2002 age_60b2002
			using "$BASE\RPS_calorie_data.out", comma replace;
clear matrix;		
clear;	
